@@ -16,7 +16,8 @@ GLOBAL_CONFIG_PATH: str = os.path.join(
     GLOBAL_WORKDIR, "config.yaml")
 LOCAL_CONFIG_PATH: str = os.path.join(
     DEFAULT_LOCAL_WORKDIR if LOCAL_WORKDIR is None else LOCAL_WORKDIR, "config.yaml")
-EXTRA_CONFIG_PATH: str = os.environ.get('wton_CONFIG_PATH')
+EXTRA_CONFIG_PATH: str = os.environ.get('WTON_CONFIG_PATH')
+CURRENT_CONFIG_PATH = os.path.join(CURRENT_WORKDIR, "config.yaml")
 CONFIG_PATHS: List[str] = [
     GLOBAL_CONFIG_PATH, LOCAL_CONFIG_PATH]
 if EXTRA_CONFIG_PATH:
