@@ -1,7 +1,7 @@
 import click
 
 from ._base_cmd import cli, SharedObject
-from .._utils import CustomClickException, with_keystores, with_keystore
+from .._utils import CustomClickException, with_keystores, with_keystore, click_echo_success
 from ..._utils import new_keystore_password_is_valid
 from wton.tonclient.utils import KeyStoreAlreadyExistsError, KeyStoreInvalidPasswordError, InvalidMnemonicsError
 from wton import settings
@@ -37,6 +37,7 @@ def new(shared_object: SharedObject, name, password):
     except KeyStoreAlreadyExistsError as e:
         raise CustomClickException(e)
 
+    click_echo_success(f"keystore {name} has been created. To use it run 'wton config wton.keystore_name {name}'.")
 
 @keystore.command()
 @with_keystores
@@ -67,6 +68,8 @@ def backup(shared_object: SharedObject, backup_file_path: str, is_sure: bool):
     except (KeyStoreInvalidPasswordError) as e:
         raise CustomClickException(e)
 
+    click_echo_success(f"keystore {shared_object.config.wton.keystore_name} has been backed up to the {backup_file_path}.")
+
 
 @keystore.command()
 @with_keystores
@@ -90,3 +93,5 @@ def restore(shared_object: SharedObject, name: str, backup_file_path: str, passw
                 name, backup_file_path, password)
     except (InvalidMnemonicsError, KeyStoreAlreadyExistsError) as e:
         raise CustomClickException(e)
+
+    click_echo_success(f"keystore {name} has been restored.")
