@@ -4,10 +4,11 @@ import click
 from wton.utils import storage
 
 from ._base_cmd import cli, SharedObject
-from .._utils import CustomClickException, with_whitelist, with_keystore, click_ton_exception_handler, click_echo_success
+from .._utils import CustomClickException, with_whitelist, with_keystore, click_ton_exception_handler, \
+    click_echo_success
 from ..._utils import md_table
 from wton.tonsdk.contract.wallet import SendModeEnum, WalletVersionEnum, Wallets
-from wton.tonclient.utils import RecordAlreadyExistsError, RecordDoesNotExistError,\
+from wton.tonclient.utils import RecordAlreadyExistsError, RecordDoesNotExistError, \
     WhitelistContactDoesNotExistError, KeyStoreInvalidPasswordError, InvalidMnemonicsError
 from wton.tonsdk.utils import TonCurrencyEnum, Address
 from wton.tonclient import ton_exceptions_handler
@@ -29,7 +30,8 @@ def wallet():
 @click.option('--comment', help='Extra information about the wallet.')
 @click.option('--save-to-whitelist', 'contact_name', help='Contact name to save.', metavar='NAME')
 @click.pass_obj
-def create(shared_object: SharedObject, name: str, version: str, workchain: int, comment: str, contact_name: str):
+def create(shared_object: SharedObject, name: str, version: str, workchain: int, comment: str,
+           contact_name: str):
     """
     Create wallet data and add it to the keystore.
     """
@@ -57,6 +59,7 @@ def create(shared_object: SharedObject, name: str, version: str, workchain: int,
 
     click_echo_success(f"wallet {name} has been created.")
 
+
 @wallet.command()
 @with_keystore(password_required=False)
 @with_whitelist
@@ -76,6 +79,7 @@ def edit(shared_object: SharedObject, name: str, new_name: str, new_comment: str
 
     click_echo_success(f"wallet {name} has been edited.")
 
+
 @wallet.command()
 @with_keystore(password_required=False)
 @with_whitelist
@@ -97,6 +101,7 @@ def delete(shared_object: SharedObject, name: str, is_sure: bool):
 
     click_echo_success(f"wallet {name} has been deleted.")
 
+
 @wallet.command()
 @with_keystore(password_required=False)
 @with_whitelist
@@ -134,8 +139,10 @@ def get(shared_object: SharedObject, name: str, verbose: bool):
 @wallet.command()
 @ton_exceptions_handler(click_ton_exception_handler)
 @with_keystore(password_required=False)
-@click.option('--currency', '-c', default=TonCurrencyEnum.ton, show_default=True, type=click.Choice(TonCurrencyEnum))
-@click.option('--verbose', '-v', 'verbose', is_flag=True, default=False, help="Extra information from TON.")
+@click.option('--currency', '-c', default=TonCurrencyEnum.ton, show_default=True,
+              type=click.Choice(TonCurrencyEnum))
+@click.option('--verbose', '-v', 'verbose', is_flag=True, default=False,
+              help="Extra information from TON.")
 @click.pass_obj
 def list(shared_object: SharedObject, verbose: bool, currency: TonCurrencyEnum):
     """
@@ -176,8 +183,8 @@ def list(shared_object: SharedObject, verbose: bool, currency: TonCurrencyEnum):
 @click.option('--comment', help='Extra information about the wallet.')
 @click.option('--save-to-whitelist', 'contact_name', help='Contact name to save.', metavar='NAME')
 @click.pass_obj
-def import_from_mnemonics(shared_object: SharedObject, name: str, version: str, workchain: int,
-                          mnemonics: str, comment: str, contact_name: str):
+def import_from_mnemonics(shared_object: SharedObject, name: str, version: str,
+                          workchain: int, mnemonics: str, comment: str, contact_name: str):
     """
     Create wallet data from mnemonics and add it to the keystore.
     """
@@ -306,7 +313,9 @@ def transfer(shared_object: SharedObject, from_wallet, to_contact, amount, messa
             record, shared_object.keystore_password).split(" ")
         contact = shared_object.whitelist.get_contact(
             to_contact, raise_none=True)
-    except (WhitelistContactDoesNotExistError, RecordDoesNotExistError, KeyStoreInvalidPasswordError) as e:
+    except (
+            WhitelistContactDoesNotExistError, RecordDoesNotExistError,
+            KeyStoreInvalidPasswordError) as e:
         raise CustomClickException(e)
 
     send_mode = 0
